# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neuracore_types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "neuracore_types.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15neuracore_types.proto\x12\x0fneuracore_types"\x1a\n\x08\x46loatRow\x12\x0e\n\x06values\x18\x01 \x03(\x02"\x8b\x02\n\tJointData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x36\n\x06values\x18\x02 \x03(\x0b\x32&.neuracore_types.JointData.ValuesEntry\x12K\n\x11\x61\x64\x64itional_values\x18\x03 \x03(\x0b\x32\x30.neuracore_types.JointData.AdditionalValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x37\n\x15\x41\x64\x64itionalValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01"\x9f\x01\n\nCameraData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x11\n\tframe_idx\x18\x02 \x01(\x05\x12-\n\nextrinsics\x18\x03 \x03(\x0b\x32\x19.neuracore_types.FloatRow\x12-\n\nintrinsics\x18\x04 \x03(\x0b\x32\x19.neuracore_types.FloatRow\x12\r\n\x05\x66rame\x18\x05 \x01(\x0c"\x98\x01\n\x08PoseData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x31\n\x04pose\x18\x02 \x03(\x0b\x32#.neuracore_types.PoseData.PoseEntry\x1a\x46\n\tPoseEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.neuracore_types.FloatRow:\x02\x38\x01"\xa1\x01\n\x0f\x45ndEffectorData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12G\n\x0copen_amounts\x18\x02 \x03(\x0b\x32\x31.neuracore_types.EndEffectorData.OpenAmountsEntry\x1a\x32\n\x10OpenAmountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01"\xb1\x01\n\x13\x45ndEffectorPoseData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12>\n\x05poses\x18\x02 \x03(\x0b\x32/.neuracore_types.EndEffectorPoseData.PosesEntry\x1aG\n\nPosesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.neuracore_types.FloatRow:\x02\x38\x01"\xbd\x01\n\x1dParallelGripperOpenAmountData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12U\n\x0copen_amounts\x18\x02 \x03(\x0b\x32?.neuracore_types.ParallelGripperOpenAmountData.OpenAmountsEntry\x1a\x32\n\x10OpenAmountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01"o\n\x0ePointCloudData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x0e\n\x06points\x18\x02 \x01(\x0c\x12\x12\n\nrgb_points\x18\x03 \x01(\x0c\x12\x12\n\nextrinsics\x18\x04 \x01(\x0c\x12\x12\n\nintrinsics\x18\x05 \x01(\x0c"/\n\x0cLanguageData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x0c\n\x04text\x18\x02 \x01(\t"-\n\nCustomData\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "neuracore_types_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_JOINTDATA_VALUESENTRY"]._loaded_options = None
    _globals["_JOINTDATA_VALUESENTRY"]._serialized_options = b"8\001"
    _globals["_JOINTDATA_ADDITIONALVALUESENTRY"]._loaded_options = None
    _globals["_JOINTDATA_ADDITIONALVALUESENTRY"]._serialized_options = b"8\001"
    _globals["_POSEDATA_POSEENTRY"]._loaded_options = None
    _globals["_POSEDATA_POSEENTRY"]._serialized_options = b"8\001"
    _globals["_ENDEFFECTORDATA_OPENAMOUNTSENTRY"]._loaded_options = None
    _globals["_ENDEFFECTORDATA_OPENAMOUNTSENTRY"]._serialized_options = b"8\001"
    _globals["_ENDEFFECTORPOSEDATA_POSESENTRY"]._loaded_options = None
    _globals["_ENDEFFECTORPOSEDATA_POSESENTRY"]._serialized_options = b"8\001"
    _globals["_PARALLELGRIPPEROPENAMOUNTDATA_OPENAMOUNTSENTRY"]._loaded_options = None
    _globals["_PARALLELGRIPPEROPENAMOUNTDATA_OPENAMOUNTSENTRY"]._serialized_options = (
        b"8\001"
    )
    _globals["_FLOATROW"]._serialized_start = 42
    _globals["_FLOATROW"]._serialized_end = 68
    _globals["_JOINTDATA"]._serialized_start = 71
    _globals["_JOINTDATA"]._serialized_end = 338
    _globals["_JOINTDATA_VALUESENTRY"]._serialized_start = 236
    _globals["_JOINTDATA_VALUESENTRY"]._serialized_end = 281
    _globals["_JOINTDATA_ADDITIONALVALUESENTRY"]._serialized_start = 283
    _globals["_JOINTDATA_ADDITIONALVALUESENTRY"]._serialized_end = 338
    _globals["_CAMERADATA"]._serialized_start = 341
    _globals["_CAMERADATA"]._serialized_end = 500
    _globals["_POSEDATA"]._serialized_start = 503
    _globals["_POSEDATA"]._serialized_end = 655
    _globals["_POSEDATA_POSEENTRY"]._serialized_start = 585
    _globals["_POSEDATA_POSEENTRY"]._serialized_end = 655
    _globals["_ENDEFFECTORDATA"]._serialized_start = 658
    _globals["_ENDEFFECTORDATA"]._serialized_end = 819
    _globals["_ENDEFFECTORDATA_OPENAMOUNTSENTRY"]._serialized_start = 769
    _globals["_ENDEFFECTORDATA_OPENAMOUNTSENTRY"]._serialized_end = 819
    _globals["_ENDEFFECTORPOSEDATA"]._serialized_start = 822
    _globals["_ENDEFFECTORPOSEDATA"]._serialized_end = 999
    _globals["_ENDEFFECTORPOSEDATA_POSESENTRY"]._serialized_start = 928
    _globals["_ENDEFFECTORPOSEDATA_POSESENTRY"]._serialized_end = 999
    _globals["_PARALLELGRIPPEROPENAMOUNTDATA"]._serialized_start = 1002
    _globals["_PARALLELGRIPPEROPENAMOUNTDATA"]._serialized_end = 1191
    _globals["_PARALLELGRIPPEROPENAMOUNTDATA_OPENAMOUNTSENTRY"]._serialized_start = 769
    _globals["_PARALLELGRIPPEROPENAMOUNTDATA_OPENAMOUNTSENTRY"]._serialized_end = 819
    _globals["_POINTCLOUDDATA"]._serialized_start = 1193
    _globals["_POINTCLOUDDATA"]._serialized_end = 1304
    _globals["_LANGUAGEDATA"]._serialized_start = 1306
    _globals["_LANGUAGEDATA"]._serialized_end = 1353
    _globals["_CUSTOMDATA"]._serialized_start = 1355
    _globals["_CUSTOMDATA"]._serialized_end = 1400
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3
"""Generate compiled Python + TypeScript code from .proto files."""

import subprocess
from pathlib import Path


def compile_protos():
    root = Path(__file__).parent.parent
    proto_file = root / "neuracore_types" / "neuracore_types.proto"

    output_dir = root / "neuracore_types"

    # python/mypy generation
    python_cmd = [
        "python",
        "-m",
        "grpc_tools.protoc",
        "-I",
        str(proto_file.parent),
        f"--python_out={output_dir}",
        f"--mypy_out={output_dir}",
        str(proto_file),
    ]
    subprocess.run(python_cmd, check=True)

    # typeScript generation
    ts_cmd = [
        "npx",
        "protoc",
        "-I",
        str(proto_file.parent),
        f"--js_out=import_style=commonjs,binary:{output_dir}",
        f"--ts_out={output_dir}",
        str(proto_file),
    ]
    subprocess.run(ts_cmd, check=True)


if __name__ == "__main__":
    compile_protos()
